===============================
kubespray package manager
===============================

.. image:: https://img.shields.io/pypi/v/kpm.svg
        :target: https://pypi.python.org/pypi/kpm

.. image:: https://img.shields.io/travis/ant31/kpm.svg
        :target: https://travis-ci.org/ant31/kpm

.. image:: https://readthedocs.org/projects/kpm/badge/?version=latest
        :target: https://readthedocs.org/projects/kpm/?badge=latest
        :alt: Documentation Status


Registry of kubernetes ready to use applications

* Free software: ISC license
* Documentation: https://kpm.readthedocs.org.

Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
